@@ -7,6 +7,8 @@
 
 struct Syntax {
         char *indent;
+        char *lbreak;
+        char *quoteval;
         char *def;
         char *def_sep;
         char *hash_outer;
@@ -16,13 +18,16 @@ struct Syntax {
         char *array_inner;
         char *adef_sep;
         char *return_hash_outer;
+        char *return_lasthash_outer;
         char *return_array_outer;
         char *return_hash_inner;
+        char *return_lasthash_inner;
         char *return_array_inner;
 };
 
 extern struct Syntax perl_syntax;
 extern struct Syntax python_syntax;
+extern struct Syntax json_syntax;
 extern struct Syntax ruby_syntax;
 extern struct Syntax debug_syntax;
 
